==> haskell-genvalidity-1.1.1.0-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity
version:              1.1.1.0
visibility:           public
id:                   genvalidity-1.1.1.0-BMmh2UQMgY15hSTp1cI43w
key:                  genvalidity-1.1.1.0-BMmh2UQMgY15hSTp1cI43w
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  6574c90525c1155e75523a86b60feb8a
exposed:              True
exposed-modules:      Data.GenValidity Data.GenValidity.Utils
hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-1.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity
hs-libraries:         HSgenvalidity-1.1.1.0-BMmh2UQMgY15hSTp1cI43w
depends:
    QuickCheck-2.14.3-KBQtot6OiBttU8xgKWkQ base-4.17.2.1
    random-1.2.1.3-KpUTlSxpYoQ2cUlPZmFoDo
    validity-0.12.1.0-6ymQiEd8kTF7WAFxMFRUn1

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-1.1.1.0-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity
version:              1.1.1.0
visibility:           public
id:                   genvalidity-1.1.1.0-2bGUCWYgQZa1QPguSMVhGE
key:                  genvalidity-1.1.1.0-2bGUCWYgQZa1QPguSMVhGE
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  686b9344217134cc63dbcd63f995bc66
exposed:              True
exposed-modules:      Data.GenValidity Data.GenValidity.Utils
hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-1.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity
hs-libraries:         HSgenvalidity-1.1.1.0-2bGUCWYgQZa1QPguSMVhGE
depends:
    QuickCheck-2.14.3-3S3WOBL6rHa3L0CMYI1WVh base-4.17.2.1
    random-1.2.1.3-1e4k6oKN9kc4OrDtxhM2uQ
    validity-0.12.1.0-Li2tIvrY3o19blMhc1iSHR

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
